Carbon Design System - Carbon Components
================

Shim [repository](https://github.com/carbon-components/carbon-components) for the [carbon-components](https://github.com/IBM/carbon-components).


Use npm/yarn to install dependency `carbon-components/carbon-components` to download a light weight repo.
